@@ -127,6 +127,7 @@ opencv_type_enum! { crate::cudacodec::SurfaceFormat }
 /// ## Overloaded parameters
 /// 
 /// * source: RAW video source implemented by user.
+#[inline]
 pub fn create_video_reader_1(source: &core::Ptr<dyn crate::cudacodec::RawVideoSource>) -> Result<core::Ptr<dyn crate::cudacodec::VideoReader>> {
 	unsafe { sys::cv_cudacodec_createVideoReader_const_Ptr_RawVideoSource_R(source.as_raw_PtrOfRawVideoSource()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoReader>::opencv_from_extern(r) } )
 }
@@ -137,6 +138,7 @@ pub fn create_video_reader_1(source: &core::Ptr<dyn crate::cudacodec::RawVideoSo
 /// * filename: Name of the input video file.
 /// 
 /// FFMPEG is used to read videos. User can implement own demultiplexing with cudacodec::RawVideoSource
+#[inline]
 pub fn create_video_reader(filename: &str) -> Result<core::Ptr<dyn crate::cudacodec::VideoReader>> {
 	extern_container_arg!(filename);
 	unsafe { sys::cv_cudacodec_createVideoReader_const_StringR(filename.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoReader>::opencv_from_extern(r) } )
@@ -167,6 +169,7 @@ pub fn create_video_reader(filename: &str) -> Result<core::Ptr<dyn crate::cudaco
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
+#[inline]
 pub fn create_video_writer_2(encoder_callback: &core::Ptr<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_Ptr_EncoderCallBack_R_Size_double_SurfaceFormat(encoder_callback.as_raw_PtrOfEncoderCallBack(), frame_size.opencv_as_extern(), fps, format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
@@ -197,6 +200,7 @@ pub fn create_video_writer_2(encoder_callback: &core::Ptr<dyn crate::cudacodec::
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
+#[inline]
 pub fn create_video_writer_3(encoder_callback: &core::Ptr<dyn crate::cudacodec::EncoderCallBack>, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_Ptr_EncoderCallBack_R_Size_double_const_EncoderParamsR_SurfaceFormat(encoder_callback.as_raw_PtrOfEncoderCallBack(), frame_size.opencv_as_extern(), fps, params.as_raw_EncoderParams(), format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
 }
@@ -216,6 +220,7 @@ pub fn create_video_writer_3(encoder_callback: &core::Ptr<dyn crate::cudacodec::
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
+#[inline]
 pub fn create_video_writer(file_name: &str, frame_size: core::Size, fps: f64, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	extern_container_arg!(file_name);
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_StringR_Size_double_SurfaceFormat(file_name.opencv_as_extern(), frame_size.opencv_as_extern(), fps, format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
@@ -246,6 +251,7 @@ pub fn create_video_writer(file_name: &str, frame_size: core::Size, fps: f64, fo
 /// 
 /// ## C++ default parameters
 /// * format: SF_BGR
+#[inline]
 pub fn create_video_writer_1(file_name: &str, frame_size: core::Size, fps: f64, params: &crate::cudacodec::EncoderParams, format: crate::cudacodec::SurfaceFormat) -> Result<core::Ptr<dyn crate::cudacodec::VideoWriter>> {
 	extern_container_arg!(file_name);
 	unsafe { sys::cv_cudacodec_createVideoWriter_const_StringR_Size_double_const_EncoderParamsR_SurfaceFormat(file_name.opencv_as_extern(), frame_size.opencv_as_extern(), fps, params.as_raw_EncoderParams(), format) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudacodec::VideoWriter>::opencv_from_extern(r) } )
@@ -263,11 +269,13 @@ pub trait EncoderCallBack: crate::cudacodec::EncoderCallBackConst {
 	/// Callback function to signal the start of bitstream that is to be encoded.
 	/// 
 	/// Callback must allocate buffer for CUDA encoder and return pointer to it and it's size.
+	#[inline]
 	fn acquire_bit_stream(&mut self, buffer_size: &mut i32) -> Result<&mut u8> {
 		unsafe { sys::cv_cudacodec_EncoderCallBack_acquireBitStream_intX(self.as_raw_mut_EncoderCallBack(), buffer_size) }.into_result().and_then(|x| unsafe { x.as_mut() }.ok_or_else(|| Error::new(core::StsNullPtr, "Function returned Null pointer".to_string())))
 	}
 	
 	/// Callback function to signal that the encoded bitstream is ready to be written to file.
+	#[inline]
 	fn release_bit_stream(&mut self, data: &mut u8, size: i32) -> Result<()> {
 		unsafe { sys::cv_cudacodec_EncoderCallBack_releaseBitStream_unsigned_charX_int(self.as_raw_mut_EncoderCallBack(), data, size) }.into_result()
 	}
@@ -277,6 +285,7 @@ pub trait EncoderCallBack: crate::cudacodec::EncoderCallBackConst {
 	/// ## Parameters
 	/// * frameNumber: 
 	/// * picType: Specify frame type (I-Frame, P-Frame or B-Frame).
+	#[inline]
 	fn on_begin_frame(&mut self, frame_number: i32, pic_type: crate::cudacodec::EncoderCallBack_PicType) -> Result<()> {
 		unsafe { sys::cv_cudacodec_EncoderCallBack_onBeginFrame_int_PicType(self.as_raw_mut_EncoderCallBack(), frame_number, pic_type) }.into_result()
 	}
@@ -286,6 +295,7 @@ pub trait EncoderCallBack: crate::cudacodec::EncoderCallBackConst {
 	/// ## Parameters
 	/// * frameNumber: 
 	/// * picType: Specify frame type (I-Frame, P-Frame or B-Frame).
+	#[inline]
 	fn on_end_frame(&mut self, frame_number: i32, pic_type: crate::cudacodec::EncoderCallBack_PicType) -> Result<()> {
 		unsafe { sys::cv_cudacodec_EncoderCallBack_onEndFrame_int_PicType(self.as_raw_mut_EncoderCallBack(), frame_number, pic_type) }.into_result()
 	}
@@ -297,96 +307,115 @@ pub trait EncoderParamsTraitConst {
 	fn as_raw_EncoderParams(&self) -> *const c_void;
 
 	/// NVVE_P_INTERVAL,
+	#[inline]
 	fn p_interval(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropP_Interval_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: p_interval")
 	}
 	
 	/// NVVE_IDR_PERIOD,
+	#[inline]
 	fn idr_period(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropIDR_Period_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: idr_period")
 	}
 	
 	/// NVVE_DYNAMIC_GOP,
+	#[inline]
 	fn dynamic_gop(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropDynamicGOP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: dynamic_gop")
 	}
 	
 	/// NVVE_RC_TYPE,
+	#[inline]
 	fn rc_type(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropRCType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: rc_type")
 	}
 	
 	/// NVVE_AVG_BITRATE,
+	#[inline]
 	fn avg_bitrate(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropAvgBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: avg_bitrate")
 	}
 	
 	/// NVVE_PEAK_BITRATE,
+	#[inline]
 	fn peak_bitrate(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropPeakBitrate_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: peak_bitrate")
 	}
 	
 	/// NVVE_QP_LEVEL_INTRA,
+	#[inline]
 	fn qp_level_intra(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_Intra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_intra")
 	}
 	
 	/// NVVE_QP_LEVEL_INTER_P,
+	#[inline]
 	fn qp_level_inter_p(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterP_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_p")
 	}
 	
 	/// NVVE_QP_LEVEL_INTER_B,
+	#[inline]
 	fn qp_level_inter_b(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropQP_Level_InterB_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: qp_level_inter_b")
 	}
 	
 	/// NVVE_DEBLOCK_MODE,
+	#[inline]
 	fn deblock_mode(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropDeblockMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: deblock_mode")
 	}
 	
 	/// NVVE_PROFILE_LEVEL,
+	#[inline]
 	fn profile_level(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropProfileLevel_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: profile_level")
 	}
 	
 	/// NVVE_FORCE_INTRA,
+	#[inline]
 	fn force_intra(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIntra_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_intra")
 	}
 	
 	/// NVVE_FORCE_IDR,
+	#[inline]
 	fn force_idr(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropForceIDR_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: force_idr")
 	}
 	
 	/// NVVE_CLEAR_STAT,
+	#[inline]
 	fn clear_stat(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropClearStat_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: clear_stat")
 	}
 	
 	/// NVVE_SET_DEINTERLACE,
+	#[inline]
 	fn di_mode(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropDIMode_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: di_mode")
 	}
 	
 	/// NVVE_PRESETS,
+	#[inline]
 	fn presets(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropPresets_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: presets")
 	}
 	
 	/// NVVE_DISABLE_CABAC,
+	#[inline]
 	fn disable_cabac(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableCabac_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_cabac")
 	}
 	
 	/// NVVE_CONFIGURE_NALU_FRAMING_TYPE
+	#[inline]
 	fn nalu_framing_type(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropNaluFramingType_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: nalu_framing_type")
 	}
 	
 	/// NVVE_DISABLE_SPS_PPS
+	#[inline]
 	fn disable_spspps(&self) -> i32 {
 		unsafe { sys::cv_cudacodec_EncoderParams_getPropDisableSPSPPS_const(self.as_raw_EncoderParams()) }.into_result().expect("Infallible function failed: disable_spspps")
 	}
@@ -395,6 +424,7 @@ pub trait EncoderParamsTraitConst {
 	/// 
 	/// ## Parameters
 	/// * configFile: Config file name.
+	#[inline]
 	fn save(&self, config_file: &str) -> Result<()> {
 		extern_container_arg!(config_file);
 		unsafe { sys::cv_cudacodec_EncoderParams_save_const_const_StringR(self.as_raw_EncoderParams(), config_file.opencv_as_extern()) }.into_result()
@@ -406,97 +436,116 @@ pub trait EncoderParamsTrait: crate::cudacodec::EncoderParamsTraitConst {
 	fn as_raw_mut_EncoderParams(&mut self) -> *mut c_void;
 
 	/// NVVE_P_INTERVAL,
-	fn set_p_interval(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_p_interval(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropP_Interval_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_p_interval")
 	}
 	
 	/// NVVE_IDR_PERIOD,
-	fn set_idr_period(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_idr_period(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropIDR_Period_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_idr_period")
 	}
 	
 	/// NVVE_DYNAMIC_GOP,
-	fn set_dynamic_gop(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_dynamic_gop(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDynamicGOP_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_dynamic_gop")
 	}
 	
 	/// NVVE_RC_TYPE,
-	fn set_rc_type(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_rc_type(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropRCType_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_rc_type")
 	}
 	
 	/// NVVE_AVG_BITRATE,
-	fn set_avg_bitrate(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_avg_bitrate(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropAvgBitrate_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_avg_bitrate")
 	}
 	
 	/// NVVE_PEAK_BITRATE,
-	fn set_peak_bitrate(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_peak_bitrate(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropPeakBitrate_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_peak_bitrate")
 	}
 	
 	/// NVVE_QP_LEVEL_INTRA,
-	fn set_qp_level_intra(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_qp_level_intra(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_Intra_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_intra")
 	}
 	
 	/// NVVE_QP_LEVEL_INTER_P,
-	fn set_qp_level_inter_p(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_qp_level_inter_p(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_InterP_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_inter_p")
 	}
 	
 	/// NVVE_QP_LEVEL_INTER_B,
-	fn set_qp_level_inter_b(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_qp_level_inter_b(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropQP_Level_InterB_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_qp_level_inter_b")
 	}
 	
 	/// NVVE_DEBLOCK_MODE,
-	fn set_deblock_mode(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_deblock_mode(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDeblockMode_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_deblock_mode")
 	}
 	
 	/// NVVE_PROFILE_LEVEL,
-	fn set_profile_level(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_profile_level(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropProfileLevel_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_profile_level")
 	}
 	
 	/// NVVE_FORCE_INTRA,
-	fn set_force_intra(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_force_intra(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropForceIntra_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_force_intra")
 	}
 	
 	/// NVVE_FORCE_IDR,
-	fn set_force_idr(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_force_idr(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropForceIDR_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_force_idr")
 	}
 	
 	/// NVVE_CLEAR_STAT,
-	fn set_clear_stat(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_clear_stat(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropClearStat_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_clear_stat")
 	}
 	
 	/// NVVE_SET_DEINTERLACE,
-	fn set_di_mode(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_di_mode(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDIMode_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_di_mode")
 	}
 	
 	/// NVVE_PRESETS,
-	fn set_presets(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_presets(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropPresets_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_presets")
 	}
 	
 	/// NVVE_DISABLE_CABAC,
-	fn set_disable_cabac(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_disable_cabac(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDisableCabac_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_disable_cabac")
 	}
 	
 	/// NVVE_CONFIGURE_NALU_FRAMING_TYPE
-	fn set_nalu_framing_type(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_nalu_framing_type(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropNaluFramingType_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_nalu_framing_type")
 	}
 	
 	/// NVVE_DISABLE_SPS_PPS
-	fn set_disable_spspps(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_disable_spspps(&mut self, val: i32) {
 		unsafe { sys::cv_cudacodec_EncoderParams_setPropDisableSPSPPS_int(self.as_raw_mut_EncoderParams(), val) }.into_result().expect("Infallible function failed: set_disable_spspps")
 	}
 	
@@ -504,6 +553,7 @@ pub trait EncoderParamsTrait: crate::cudacodec::EncoderParamsTraitConst {
 	/// 
 	/// ## Parameters
 	/// * configFile: Config file name.
+	#[inline]
 	fn load(&mut self, config_file: &str) -> Result<()> {
 		extern_container_arg!(config_file);
 		unsafe { sys::cv_cudacodec_EncoderParams_load_const_StringR(self.as_raw_mut_EncoderParams(), config_file.opencv_as_extern()) }.into_result()
@@ -536,6 +586,7 @@ impl crate::cudacodec::EncoderParamsTrait for EncoderParams {
 }
 
 impl EncoderParams {
+	#[inline]
 	pub fn default() -> Result<crate::cudacodec::EncoderParams> {
 		unsafe { sys::cv_cudacodec_EncoderParams_EncoderParams() }.into_result().map(|r| unsafe { crate::cudacodec::EncoderParams::opencv_from_extern(r) } )
 	}
@@ -546,6 +597,7 @@ impl EncoderParams {
 	/// * configFile: Config file name.
 	/// 
 	/// Creates default parameters or reads parameters from config file.
+	#[inline]
 	pub fn new(config_file: &str) -> Result<crate::cudacodec::EncoderParams> {
 		extern_container_arg!(config_file);
 		unsafe { sys::cv_cudacodec_EncoderParams_EncoderParams_const_StringR(config_file.opencv_as_extern()) }.into_result().map(|r| unsafe { crate::cudacodec::EncoderParams::opencv_from_extern(r) } )
@@ -560,8 +612,13 @@ pub struct FormatInfo {
 	pub codec: crate::cudacodec::Codec,
 	pub chroma_format: crate::cudacodec::ChromaFormat,
 	pub n_bit_depth_minus8: i32,
+	/// Width of the decoded frame returned by nextFrame(frame)
 	pub width: i32,
+	/// Height of the decoded frame returned by nextFrame(frame)
 	pub height: i32,
+	/// ROI inside the decoded frame returned by nextFrame(frame), containing the useable video frame.
+	pub display_area: core::Rect,
+	pub valid: bool,
 }
 
 opencv_type_simple! { crate::cudacodec::FormatInfo }
@@ -576,6 +633,7 @@ pub trait RawVideoSourceConst {
 	fn as_raw_RawVideoSource(&self) -> *const c_void;
 
 	/// Returns information about video file format.
+	#[inline]
 	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
 		unsafe { sys::cv_cudacodec_RawVideoSource_format_const(self.as_raw_RawVideoSource()) }.into_result()
 	}
@@ -590,10 +648,17 @@ pub trait RawVideoSource: crate::cudacodec::RawVideoSourceConst {
 	/// ## Parameters
 	/// * data: Pointer to frame data.
 	/// * size: Size in bytes of current frame.
+	#[inline]
 	fn get_next_packet(&mut self, data: &mut &mut u8, size: &mut size_t) -> Result<bool> {
 		unsafe { sys::cv_cudacodec_RawVideoSource_getNextPacket_unsigned_charXX_size_tX(self.as_raw_mut_RawVideoSource(), data as *mut  _ as *mut  *mut  _, size) }.into_result()
 	}
 	
+	/// Updates the coded width and height inside format.
+	#[inline]
+	fn update_format(&mut self, coded_width: i32, coded_height: i32) -> Result<()> {
+		unsafe { sys::cv_cudacodec_RawVideoSource_updateFormat_const_int_const_int(self.as_raw_mut_RawVideoSource(), coded_width, coded_height) }.into_result()
+	}
+	
 }
 
 /// Video reader interface.
@@ -606,6 +671,7 @@ pub trait VideoReaderConst {
 	fn as_raw_VideoReader(&self) -> *const c_void;
 
 	/// Returns information about video file format.
+	#[inline]
 	fn format(&self) -> Result<crate::cudacodec::FormatInfo> {
 		unsafe { sys::cv_cudacodec_VideoReader_format_const(self.as_raw_VideoReader()) }.into_result()
 	}
@@ -622,6 +688,7 @@ pub trait VideoReader: crate::cudacodec::VideoReaderConst {
 	/// 
 	/// ## C++ default parameters
 	/// * stream: Stream::Null()
+	#[inline]
 	fn next_frame(&mut self, frame: &mut core::GpuMat, stream: &mut core::Stream) -> Result<bool> {
 		unsafe { sys::cv_cudacodec_VideoReader_nextFrame_GpuMatR_StreamR(self.as_raw_mut_VideoReader(), frame.as_raw_mut_GpuMat(), stream.as_raw_mut_Stream()) }.into_result()
 	}
@@ -642,6 +709,7 @@ pub trait VideoReader: crate::cudacodec::VideoReaderConst {
 pub trait VideoWriterConst {
 	fn as_raw_VideoWriter(&self) -> *const c_void;
 
+	#[inline]
 	fn get_encoder_params(&self) -> Result<crate::cudacodec::EncoderParams> {
 		unsafe { sys::cv_cudacodec_VideoWriter_getEncoderParams_const(self.as_raw_VideoWriter()) }.into_result().map(|r| unsafe { crate::cudacodec::EncoderParams::opencv_from_extern(r) } )
 	}
@@ -662,6 +730,7 @@ pub trait VideoWriter: crate::cudacodec::VideoWriterConst {
 	/// 
 	/// ## C++ default parameters
 	/// * last_frame: false
+	#[inline]
 	fn write(&mut self, frame: &dyn core::ToInputArray, last_frame: bool) -> Result<()> {
 		input_array_arg!(frame);
 		unsafe { sys::cv_cudacodec_VideoWriter_write_const__InputArrayR_bool(self.as_raw_mut_VideoWriter(), frame.as_raw__InputArray(), last_frame) }.into_result()
