@@ -23,7 +23,7 @@
 //!    # OpenGL support
 //!    # Qt New Functions
 //! 
-//!    ![image](https://docs.opencv.org/4.5.3/qtgui.png)
+//!    ![image](https://docs.opencv.org/4.5.4/qtgui.png)
 //! 
 //!    This figure explains new functionality implemented with Qt\* GUI. The new GUI provides a statusbar,
 //!    a toolbar, and a control panel. The control panel can have trackbars and buttonbars attached to it.
@@ -397,6 +397,7 @@ pub type TrackbarCallback = Option<Box<dyn FnMut(i32) -> () + Send + Sync + 'sta
 /// * text: Text to write on an image.
 /// * org: Point(x,y) where the text should start on an image.
 /// * font: Font to use to draw a text.
+#[inline]
 pub fn add_text(img: &core::Mat, text: &str, org: core::Point, font: &crate::highgui::QtFont) -> Result<()> {
 	extern_container_arg!(text);
 	unsafe { sys::cv_addText_const_MatR_const_StringR_Point_const_QtFontR(img.as_raw_Mat(), text.opencv_as_extern(), org.opencv_as_extern(), font.as_raw_QtFont()) }.into_result()
@@ -423,6 +424,7 @@ pub fn add_text(img: &core::Mat, text: &str, org: core::Point, font: &crate::hig
 /// * weight: QT_FONT_NORMAL
 /// * style: QT_STYLE_NORMAL
 /// * spacing: 0
+#[inline]
 pub fn add_text_with_font(img: &core::Mat, text: &str, org: core::Point, name_font: &str, point_size: i32, color: core::Scalar, weight: i32, style: i32, spacing: i32) -> Result<()> {
 	extern_container_arg!(text);
 	extern_container_arg!(name_font);
@@ -461,6 +463,7 @@ pub fn add_text_with_font(img: &core::Mat, text: &str, org: core::Point, name_fo
 /// * userdata: 0
 /// * typ: QT_PUSH_BUTTON
 /// * initial_button_state: false
+#[inline]
 pub fn create_button(bar_name: &str, on_change: crate::highgui::ButtonCallback, typ: i32, initial_button_state: bool) -> Result<i32> {
 	extern_container_arg!(bar_name);
 	callback_arg!(on_change_trampoline(state: i32, userdata: *mut c_void) -> () => userdata in callbacks => on_change(state: i32) -> ());
@@ -499,6 +502,7 @@ pub fn create_button(bar_name: &str, on_change: crate::highgui::ButtonCallback,
 /// ## C++ default parameters
 /// * on_change: 0
 /// * userdata: 0
+#[inline]
 pub fn create_trackbar(trackbarname: &str, winname: &str, value: Option<&mut i32>, count: i32, on_change: crate::highgui::TrackbarCallback) -> Result<i32> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
@@ -510,6 +514,7 @@ pub fn create_trackbar(trackbarname: &str, winname: &str, value: Option<&mut i32
 /// Destroys all of the HighGUI windows.
 /// 
 /// The function destroyAllWindows destroys all of the opened HighGUI windows.
+#[inline]
 pub fn destroy_all_windows() -> Result<()> {
 	unsafe { sys::cv_destroyAllWindows() }.into_result()
 }
@@ -520,6 +525,7 @@ pub fn destroy_all_windows() -> Result<()> {
 /// 
 /// ## Parameters
 /// * winname: Name of the window to be destroyed.
+#[inline]
 pub fn destroy_window(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_destroyWindow_const_StringR(winname.opencv_as_extern()) }.into_result()
@@ -540,6 +546,7 @@ pub fn destroy_window(winname: &str) -> Result<()> {
 /// 
 /// ## C++ default parameters
 /// * delayms: 0
+#[inline]
 pub fn display_overlay(winname: &str, text: &str, delayms: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(text);
@@ -561,6 +568,7 @@ pub fn display_overlay(winname: &str, text: &str, delayms: i32) -> Result<()> {
 /// 
 /// ## C++ default parameters
 /// * delayms: 0
+#[inline]
 pub fn display_status_bar(winname: &str, text: &str, delayms: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(text);
@@ -595,6 +603,7 @@ pub fn display_status_bar(winname: &str, text: &str, delayms: i32) -> Result<()>
 /// * weight: QT_FONT_NORMAL
 /// * style: QT_STYLE_NORMAL
 /// * spacing: 0
+#[inline]
 pub fn font_qt(name_font: &str, point_size: i32, color: core::Scalar, weight: i32, style: i32, spacing: i32) -> Result<crate::highgui::QtFont> {
 	extern_container_arg!(name_font);
 	unsafe { sys::cv_fontQt_const_StringR_int_Scalar_int_int_int(name_font.opencv_as_extern(), point_size, color.opencv_as_extern(), weight, style, spacing) }.into_result().map(|r| unsafe { crate::highgui::QtFont::opencv_from_extern(r) } )
@@ -619,6 +628,7 @@ pub fn font_qt(name_font: &str, point_size: i32, color: core::Scalar, weight: i3
 /// 
 /// ## Parameters
 /// * flags: The mouse callback flags parameter.
+#[inline]
 pub fn get_mouse_wheel_delta(flags: i32) -> Result<i32> {
 	unsafe { sys::cv_getMouseWheelDelta_int(flags) }.into_result()
 }
@@ -636,6 +646,7 @@ pub fn get_mouse_wheel_delta(flags: i32) -> Result<i32> {
 /// ## Parameters
 /// * trackbarname: Name of the trackbar.
 /// * winname: Name of the window that is the parent of the trackbar.
+#[inline]
 pub fn get_trackbar_pos(trackbarname: &str, winname: &str) -> Result<i32> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
@@ -650,6 +661,7 @@ pub fn get_trackbar_pos(trackbarname: &str, winname: &str) -> Result<i32> {
 /// * winname: Name of the window.
 /// ## See also
 /// resizeWindow moveWindow
+#[inline]
 pub fn get_window_image_rect(winname: &str) -> Result<core::Rect> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_getWindowImageRect_const_StringR(winname.opencv_as_extern()) }.into_result()
@@ -664,6 +676,7 @@ pub fn get_window_image_rect(winname: &str) -> Result<core::Rect> {
 /// * prop_id: Window property to retrieve. The following operation flags are available: (cv::WindowPropertyFlags)
 /// ## See also
 /// setWindowProperty
+#[inline]
 pub fn get_window_property(winname: &str, prop_id: i32) -> Result<f64> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_getWindowProperty_const_StringR_int(winname.opencv_as_extern(), prop_id) }.into_result()
@@ -676,10 +689,12 @@ pub fn get_window_property(winname: &str, prop_id: i32) -> Result<f64> {
 /// Otherwise, the image is scaled to fit the window. The function may scale the image, depending on its depth:
 /// 
 /// *   If the image is 8-bit unsigned, it is displayed as is.
-/// *   If the image is 16-bit unsigned or 32-bit integer, the pixels are divided by 256. That is, the
+/// *   If the image is 16-bit unsigned, the pixels are divided by 256. That is, the
 ///    value range [0,255\*256] is mapped to [0,255].
 /// *   If the image is 32-bit or 64-bit floating-point, the pixel values are multiplied by 255. That is, the
 ///    value range [0,1] is mapped to [0,255].
+/// *   32-bit integer images are not processed anymore due to ambiguouty of required transform.
+///    Convert to 8-bit unsigned matrix using a custom preprocessing specific to image's context.
 /// 
 /// If window was created with OpenGL support, cv::imshow also support ogl::Buffer , ogl::Texture2D and
 /// cuda::GpuMat as input.
@@ -706,6 +721,7 @@ pub fn get_window_property(winname: &str, prop_id: i32) -> Result<f64> {
 /// ## Parameters
 /// * winname: Name of the window.
 /// * mat: Image to be shown.
+#[inline]
 pub fn imshow(winname: &str, mat: &dyn core::ToInputArray) -> Result<()> {
 	extern_container_arg!(winname);
 	input_array_arg!(mat);
@@ -719,6 +735,7 @@ pub fn imshow(winname: &str, mat: &dyn core::ToInputArray) -> Result<()> {
 /// 
 /// ## Parameters
 /// * windowName: Name of the window.
+#[inline]
 pub fn load_window_parameters(window_name: &str) -> Result<()> {
 	extern_container_arg!(window_name);
 	unsafe { sys::cv_loadWindowParameters_const_StringR(window_name.opencv_as_extern()) }.into_result()
@@ -730,6 +747,7 @@ pub fn load_window_parameters(window_name: &str) -> Result<()> {
 /// * winname: Name of the window.
 /// * x: The new x-coordinate of the window.
 /// * y: The new y-coordinate of the window.
+#[inline]
 pub fn move_window(winname: &str, x: i32, y: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_moveWindow_const_StringR_int_int(winname.opencv_as_extern(), x, y) }.into_result()
@@ -765,6 +783,7 @@ pub fn move_window(winname: &str, x: i32, y: i32) -> Result<()> {
 /// 
 /// ## C++ default parameters
 /// * flags: WINDOW_AUTOSIZE
+#[inline]
 pub fn named_window(winname: &str, flags: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_namedWindow_const_StringR_int(winname.opencv_as_extern(), flags) }.into_result()
@@ -783,6 +802,7 @@ pub fn named_window(winname: &str, flags: i32) -> Result<()> {
 /// 
 /// Note: The function only works if there is at least one HighGUI window created and the window is
 /// active. If there are several HighGUI windows, any of them can be active.
+#[inline]
 pub fn poll_key() -> Result<i32> {
 	unsafe { sys::cv_pollKey() }.into_result()
 }
@@ -804,6 +824,7 @@ pub fn poll_key() -> Result<i32> {
 /// 
 /// * winname: Window name.
 /// * size: The new window size.
+#[inline]
 pub fn resize_window_size(winname: &str, size: core::Size) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_resizeWindow_const_StringR_const_SizeR(winname.opencv_as_extern(), &size) }.into_result()
@@ -821,6 +842,7 @@ pub fn resize_window_size(winname: &str, size: core::Size) -> Result<()> {
 /// * winname: Window name.
 /// * width: The new window width.
 /// * height: The new window height.
+#[inline]
 pub fn resize_window(winname: &str, width: i32, height: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_resizeWindow_const_StringR_int_int(winname.opencv_as_extern(), width, height) }.into_result()
@@ -833,6 +855,7 @@ pub fn resize_window(winname: &str, width: i32, height: i32) -> Result<()> {
 /// 
 /// ## Parameters
 /// * windowName: Name of the window.
+#[inline]
 pub fn save_window_parameters(window_name: &str) -> Result<()> {
 	extern_container_arg!(window_name);
 	unsafe { sys::cv_saveWindowParameters_const_StringR(window_name.opencv_as_extern()) }.into_result()
@@ -859,6 +882,7 @@ pub fn save_window_parameters(window_name: &str) -> Result<()> {
 /// ## C++ default parameters
 /// * show_crosshair: true
 /// * from_center: false
+#[inline]
 pub fn select_roi_for_window(window_name: &str, img: &dyn core::ToInputArray, show_crosshair: bool, from_center: bool) -> Result<core::Rect> {
 	extern_container_arg!(window_name);
 	input_array_arg!(img);
@@ -888,6 +912,7 @@ pub fn select_roi_for_window(window_name: &str, img: &dyn core::ToInputArray, sh
 /// ## C++ default parameters
 /// * show_crosshair: true
 /// * from_center: false
+#[inline]
 pub fn select_roi(img: &dyn core::ToInputArray, show_crosshair: bool, from_center: bool) -> Result<core::Rect> {
 	input_array_arg!(img);
 	unsafe { sys::cv_selectROI_const__InputArrayR_bool_bool(img.as_raw__InputArray(), show_crosshair, from_center) }.into_result()
@@ -914,6 +939,7 @@ pub fn select_roi(img: &dyn core::ToInputArray, show_crosshair: bool, from_cente
 /// ## C++ default parameters
 /// * show_crosshair: true
 /// * from_center: false
+#[inline]
 pub fn select_rois(window_name: &str, img: &dyn core::ToInputArray, bounding_boxes: &mut core::Vector<core::Rect>, show_crosshair: bool, from_center: bool) -> Result<()> {
 	extern_container_arg!(window_name);
 	input_array_arg!(img);
@@ -932,6 +958,7 @@ pub fn select_rois(window_name: &str, img: &dyn core::ToInputArray, bounding_box
 /// 
 /// ## C++ default parameters
 /// * userdata: 0
+#[inline]
 pub fn set_mouse_callback(winname: &str, on_mouse: crate::highgui::MouseCallback) -> Result<()> {
 	extern_container_arg!(winname);
 	callback_arg!(on_mouse_trampoline(event: i32, x: i32, y: i32, flags: i32, userdata: *mut c_void) -> () => userdata in callbacks => on_mouse(event: i32, x: i32, y: i32, flags: i32) -> ());
@@ -943,6 +970,7 @@ pub fn set_mouse_callback(winname: &str, on_mouse: crate::highgui::MouseCallback
 /// 
 /// ## Parameters
 /// * winname: Name of the window.
+#[inline]
 pub fn set_opengl_context(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_setOpenGlContext_const_StringR(winname.opencv_as_extern()) }.into_result()
@@ -992,6 +1020,7 @@ pub fn set_opengl_context(winname: &str) -> Result<()> {
 /// 
 /// ## C++ default parameters
 /// * userdata: 0
+#[inline]
 pub fn set_opengl_draw_callback(winname: &str, on_opengl_draw: crate::highgui::OpenGlDrawCallback) -> Result<()> {
 	extern_container_arg!(winname);
 	callback_arg!(on_opengl_draw_trampoline(userdata: *mut c_void) -> () => userdata in callbacks => on_opengl_draw() -> ());
@@ -1013,6 +1042,7 @@ pub fn set_opengl_draw_callback(winname: &str, on_opengl_draw: crate::highgui::O
 /// * trackbarname: Name of the trackbar.
 /// * winname: Name of the window that is the parent of trackbar.
 /// * maxval: New maximum position.
+#[inline]
 pub fn set_trackbar_max(trackbarname: &str, winname: &str, maxval: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
@@ -1033,6 +1063,7 @@ pub fn set_trackbar_max(trackbarname: &str, winname: &str, maxval: i32) -> Resul
 /// * trackbarname: Name of the trackbar.
 /// * winname: Name of the window that is the parent of trackbar.
 /// * minval: New minimum position.
+#[inline]
 pub fn set_trackbar_min(trackbarname: &str, winname: &str, minval: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
@@ -1053,6 +1084,7 @@ pub fn set_trackbar_min(trackbarname: &str, winname: &str, minval: i32) -> Resul
 /// * trackbarname: Name of the trackbar.
 /// * winname: Name of the window that is the parent of trackbar.
 /// * pos: New position.
+#[inline]
 pub fn set_trackbar_pos(trackbarname: &str, winname: &str, pos: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
@@ -1067,6 +1099,7 @@ pub fn set_trackbar_pos(trackbarname: &str, winname: &str, pos: i32) -> Result<(
 /// * winname: Name of the window.
 /// * prop_id: Window property to edit. The supported operation flags are: (cv::WindowPropertyFlags)
 /// * prop_value: New value of the window property. The supported flags are: (cv::WindowFlags)
+#[inline]
 pub fn set_window_property(winname: &str, prop_id: i32, prop_value: f64) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_setWindowProperty_const_StringR_int_double(winname.opencv_as_extern(), prop_id, prop_value) }.into_result()
@@ -1076,21 +1109,25 @@ pub fn set_window_property(winname: &str, prop_id: i32, prop_value: f64) -> Resu
 /// ## Parameters
 /// * winname: Name of the window.
 /// * title: New title.
+#[inline]
 pub fn set_window_title(winname: &str, title: &str) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(title);
 	unsafe { sys::cv_setWindowTitle_const_StringR_const_StringR(winname.opencv_as_extern(), title.opencv_as_extern()) }.into_result()
 }
 
+#[inline]
 pub fn start_loop(pt2_func: Option<unsafe extern "C" fn(i32, *mut *mut c_char) -> i32>, argc: i32, argv: &mut [&str]) -> Result<i32> {
 	string_array_arg_mut!(argv);
 	unsafe { sys::cv_startLoop_int__X__int__charXX__int_charXX(pt2_func, argc, argv.as_mut_ptr()) }.into_result()
 }
 
+#[inline]
 pub fn start_window_thread() -> Result<i32> {
 	unsafe { sys::cv_startWindowThread() }.into_result()
 }
 
+#[inline]
 pub fn stop_loop() -> Result<()> {
 	unsafe { sys::cv_stopLoop() }.into_result()
 }
@@ -1099,6 +1136,7 @@ pub fn stop_loop() -> Result<()> {
 /// 
 /// ## Parameters
 /// * winname: Name of the window.
+#[inline]
 pub fn update_window(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
 	unsafe { sys::cv_updateWindow_const_StringR(winname.opencv_as_extern()) }.into_result()
@@ -1113,6 +1151,7 @@ pub fn update_window(winname: &str) -> Result<()> {
 /// 
 /// ## C++ default parameters
 /// * delay: 0
+#[inline]
 pub fn wait_key_ex(delay: i32) -> Result<i32> {
 	unsafe { sys::cv_waitKeyEx_int(delay) }.into_result()
 }
@@ -1140,6 +1179,7 @@ pub fn wait_key_ex(delay: i32) -> Result<i32> {
 /// 
 /// ## C++ default parameters
 /// * delay: 0
+#[inline]
 pub fn wait_key(delay: i32) -> Result<i32> {
 	unsafe { sys::cv_waitKey_int(delay) }.into_result()
 }
@@ -1149,57 +1189,69 @@ pub trait QtFontTraitConst {
 	fn as_raw_QtFont(&self) -> *const c_void;
 
 	/// Name of the font
+	#[inline]
 	fn name_font(&self) -> String {
 		unsafe { sys::cv_QtFont_getPropNameFont_const(self.as_raw_QtFont()) }.into_result().map(|r| unsafe { String::opencv_from_extern(r) } ).expect("Infallible function failed: name_font")
 	}
 	
 	/// Color of the font. Scalar(blue_component, green_component, red_component[, alpha_component])
+	#[inline]
 	fn color(&self) -> core::Scalar {
 		unsafe { sys::cv_QtFont_getPropColor_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: color")
 	}
 	
 	/// See cv::QtFontStyles
+	#[inline]
 	fn font_face(&self) -> i32 {
 		unsafe { sys::cv_QtFont_getPropFont_face_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: font_face")
 	}
 	
 	/// font data and metrics
+	#[inline]
 	fn ascii(&self) -> &i32 {
 		unsafe { sys::cv_QtFont_getPropAscii_const(self.as_raw_QtFont()) }.into_result().and_then(|x| unsafe { x.as_ref() }.ok_or_else(|| Error::new(core::StsNullPtr, "Function returned Null pointer".to_string()))).expect("Infallible function failed: ascii")
 	}
 	
+	#[inline]
 	fn greek(&self) -> &i32 {
 		unsafe { sys::cv_QtFont_getPropGreek_const(self.as_raw_QtFont()) }.into_result().and_then(|x| unsafe { x.as_ref() }.ok_or_else(|| Error::new(core::StsNullPtr, "Function returned Null pointer".to_string()))).expect("Infallible function failed: greek")
 	}
 	
+	#[inline]
 	fn cyrillic(&self) -> &i32 {
 		unsafe { sys::cv_QtFont_getPropCyrillic_const(self.as_raw_QtFont()) }.into_result().and_then(|x| unsafe { x.as_ref() }.ok_or_else(|| Error::new(core::StsNullPtr, "Function returned Null pointer".to_string()))).expect("Infallible function failed: cyrillic")
 	}
 	
+	#[inline]
 	fn hscale(&self) -> f32 {
 		unsafe { sys::cv_QtFont_getPropHscale_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: hscale")
 	}
 	
+	#[inline]
 	fn vscale(&self) -> f32 {
 		unsafe { sys::cv_QtFont_getPropVscale_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: vscale")
 	}
 	
 	/// slope coefficient: 0 - normal, >0 - italic
+	#[inline]
 	fn shear(&self) -> f32 {
 		unsafe { sys::cv_QtFont_getPropShear_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: shear")
 	}
 	
 	/// See cv::QtFontWeights
+	#[inline]
 	fn thickness(&self) -> i32 {
 		unsafe { sys::cv_QtFont_getPropThickness_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: thickness")
 	}
 	
 	/// horizontal interval between letters
+	#[inline]
 	fn dx(&self) -> f32 {
 		unsafe { sys::cv_QtFont_getPropDx_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: dx")
 	}
 	
 	/// PointSize
+	#[inline]
 	fn line_type(&self) -> i32 {
 		unsafe { sys::cv_QtFont_getPropLine_type_const(self.as_raw_QtFont()) }.into_result().expect("Infallible function failed: line_type")
 	}
@@ -1210,40 +1262,48 @@ pub trait QtFontTrait: crate::highgui::QtFontTraitConst {
 	fn as_raw_mut_QtFont(&mut self) -> *mut c_void;
 
 	/// Color of the font. Scalar(blue_component, green_component, red_component[, alpha_component])
-	fn set_color(&mut self, val: core::Scalar) -> () {
+	#[inline]
+	fn set_color(&mut self, val: core::Scalar) {
 		unsafe { sys::cv_QtFont_setPropColor_Scalar(self.as_raw_mut_QtFont(), val.opencv_as_extern()) }.into_result().expect("Infallible function failed: set_color")
 	}
 	
 	/// See cv::QtFontStyles
-	fn set_font_face(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_font_face(&mut self, val: i32) {
 		unsafe { sys::cv_QtFont_setPropFont_face_int(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_font_face")
 	}
 	
-	fn set_hscale(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_hscale(&mut self, val: f32) {
 		unsafe { sys::cv_QtFont_setPropHscale_float(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_hscale")
 	}
 	
-	fn set_vscale(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_vscale(&mut self, val: f32) {
 		unsafe { sys::cv_QtFont_setPropVscale_float(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_vscale")
 	}
 	
 	/// slope coefficient: 0 - normal, >0 - italic
-	fn set_shear(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_shear(&mut self, val: f32) {
 		unsafe { sys::cv_QtFont_setPropShear_float(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_shear")
 	}
 	
 	/// See cv::QtFontWeights
-	fn set_thickness(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_thickness(&mut self, val: i32) {
 		unsafe { sys::cv_QtFont_setPropThickness_int(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_thickness")
 	}
 	
 	/// horizontal interval between letters
-	fn set_dx(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_dx(&mut self, val: f32) {
 		unsafe { sys::cv_QtFont_setPropDx_float(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_dx")
 	}
 	
 	/// PointSize
-	fn set_line_type(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_line_type(&mut self, val: i32) {
 		unsafe { sys::cv_QtFont_setPropLine_type_int(self.as_raw_mut_QtFont(), val) }.into_result().expect("Infallible function failed: set_line_type")
 	}
 	
